import React, { useState, useRef, useEffect, forwardRef, useImperativeHandle } from 'react';
import { Space, Table, Button, Image, Divider, Card, Input } from 'antd';
import type { InputRef } from 'antd';
import type { ColumnsType } from 'antd/es/table';
import { t } from '@/utils/i18n';
import { PlusOutlined, ExclamationCircleFilled, DeleteOutlined, SearchOutlined } from '@ant-design/icons';
import { antdUtils } from '@/utils/antd';
import { useRequest } from '@/hooks/use-request';
import { DataDictVO, DataDictDetailVO } from '@/models';
import DictDetailEditor from './dict-detail-editor';
import templateDictDetailService from '@/request/service/template-dict-detail';

export interface DictDetailRef {
    updateDictData: (dictData: DataDictVO) => void;
}

export default forwardRef((props, ref) => {

    const [dict, setDict] = useState<DataDictVO>();
    const [dictDetail, setDictDetail] = useState<DataDictDetailVO[]>();
    const [total, setTotal] = useState(0);

    const [detailEditorVisable, seEdtailEditorVisable] = useState<boolean>(false);
    const [editDetailData, seEditDetailData] = useState<DataDictDetailVO | null>();

    const { runAsync: getPageApi } = useRequest(templateDictDetailService.getPageApi, { manual: true });
    const { runAsync: deleteApi } = useRequest(templateDictDetailService.deleteApi, { manual: true });

    useImperativeHandle(ref, () => ({
        updateDictData: (dictData: DataDictVO) => {
            setDict(dictData);
        },
    }));

    const load = async () => {
        //TODO: setup pagenation
        const [error, { data }] = await getPageApi({ dictId: dict?.id });
        if (!error) {
            setDictDetail(data.list);
            setTotal(data.total);
        }
    }

    useEffect(() => {
        if (dict) {
            load();
        }
    }, [dict]);

    const showDeleteConfirm = (item: DataDictDetailVO) => {
        antdUtils.modal?.confirm({
            title: `确认删除标签为: ${item.label} 的字典吗?`,
            icon: <ExclamationCircleFilled />,
            content: '请注意删除以后不可恢复！',
            okText: '删除',
            okType: 'danger',
            cancelText: '取消',
            onOk: async () => {
                const [error, { code, msg }] = await deleteApi(item.id);
                if (error || code !== 0) {
                    antdUtils.message?.open({ type: 'error', content: msg ?? '操作失败' })
                } else {
                    antdUtils.message?.open({ type: 'success', content: '删除成功' })
                }
                await load();
            },
            onCancel() {
            },
        });
    };


    const columns: ColumnsType<DataDictDetailVO> = [
        {
            title: '字典标签',
            dataIndex: 'label',
            key: 'label',
            align: 'center',
            width: 150,
        },

        {
            title: '字典值',
            key: 'value',
            dataIndex: 'value',
            align: 'center',
        },
        {
            title: '排序',
            key: 'dictSort',
            dataIndex: 'dictSort',
            width: 100,
        },
        {
            title: t("QkOmYwne" /* 操作 */),
            key: 'action',
            render: (_, record) => (
                <Space size="middle" split={(
                    <Divider type='vertical' />
                )}>
                    <a
                        onClick={() => {
                            seEditDetailData(record);
                            seEdtailEditorVisable(true);
                        }}>
                        编辑
                    </a>
                    <a
                        onClick={() => {
                            showDeleteConfirm(record)
                        }}>
                        删除
                    </a>
                </Space>
            ),
            width: 150,
        },
    ];

    return (
        <>
            <div>
                <Card className='basis-3/5 mb-[10px] ml-[10px] dark:bg-[rgb(33,41,70)] bg-white roundle-lg px[12px]' bodyStyle={{
                    paddingTop: 0,
                    paddingBottom: 0
                }}>
                    <div className="py-[8px] flex justify-between w-full">
                        <div className='py-[5px]'>
                           {dict? <span className='text-center text-lg font-semibold'>所属字典: {dict?.name}</span> : null}
                        </div>
                        <Button className="ml-5" type='primary' size='middle'
                            icon={<PlusOutlined />}
                            onClick={() => {
                                seEditDetailData(null);
                                seEdtailEditorVisable(true);
                            }}
                            disabled={!dict}> 新增 </Button>
                    </div>
                    <Table rowKey="id" scroll={{ x: true }} columns={columns} dataSource={dictDetail} className='bg-transparent'
                        pagination={{ position: ['bottomRight'] }}
                    />
                </Card>
            </div>

            <DictDetailEditor
                onSave={() => {
                    load();
                    seEdtailEditorVisable(false);
                }}
                onCancel={() => { seEdtailEditorVisable(false) }}
                visible={detailEditorVisable}
                data={editDetailData}
                dictId={dict?.id}
            />
        </>
    );
});
